@@ -13,6 +13,7 @@ from pytest import raises
 
 from fields import Fields
 from fields import Tuple
+from fields import RegexValidate, ValidationError
 
 
 @fixture(params=[
@@ -46,6 +47,15 @@ def test_defaults_on_tuples():
 
     raises(TypeError, test)
 
+
+def test_required_after_defaults():
+    def test():
+        class Fail(Tuple.a['def'].b):
+            pass
+
+    raises(TypeError, test)
+
+
 def test_extra_args():
     raises(TypeError, Fields.a.b, 1, 2, 3)
 
@@ -327,3 +337,69 @@ def test_missing_arg(InitC):
     """
     with raises(TypeError):
         InitC(a=1)
+
+
+def test_regex_validator():
+    class Test(RegexValidate.value['aa+'], Fields.value):
+        pass
+
+    raises(ValidationError, Test, 'a')
+    raises(ValidationError, Test, '')
+    raises(ValidationError, Test, 'bb')
+
+    t = Test('aa')
+    assert t.value == 'aa'
+
+
+def test_regex_validator_rev():
+    class Test(Fields.value, RegexValidate.value['aa+']):
+        pass
+
+    raises(ValidationError, Test, 'a')
+    raises(ValidationError, Test, '')
+    raises(ValidationError, Test, 'bb')
+
+    t = Test('aa')
+    assert t.value == 'aa'
+
+
+def test_regex_validator_incompatible_layout():
+    def test():
+        class Test(RegexValidate.value['aa+'].extra['x'], Fields.value.extar['2'].a[3].b[4].c[5].d[6]):
+            pass
+    raises(TypeError, test)
+
+
+def test_regex_validator_incompatible_layout_2():
+    def test():
+        class Test(RegexValidate.value['aa+'], Fields.other):
+            pass
+    raises(TypeError, test)
+
+
+def test_regex_validator_rev_incompatible_layout():
+    def test():
+        class Test(Fields.value, RegexValidate.balue['aa+']):
+            pass
+    raises(TypeError, test)
+
+
+def test_init_default_args_as_positional_args():
+    class MyContainer(Fields.a.b[2].c[3]):
+        pass
+
+    assert repr(MyContainer(0, 1, 2)) == 'MyContainer(a=0, b=1, c=2)'
+
+
+def test_init_default_args_as_positional_misaligned():
+    class MyContainer(Fields.a.b[2].c[3]):
+        pass
+
+    raises(TypeError, MyContainer, 0, 1, b=2)
+
+
+def test_init_default_args_as_positional_partial():
+    class MyContainer(Fields.a.b[2].c[3]):
+        pass
+
+    assert repr(MyContainer(0, 1, c=2)) == 'MyContainer(a=0, b=1, c=2)'
